==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/account.php <==
<?php

/**
  @class Account
  @brief Class representing a generic account.
  @author Martin Zlomek
  @date 12-02-2006
 */
abstract class Account {
	/** Optional GroupWare account. */
	public $gwAccount;

	/** List of folders. */
	public $folders;

	/** Name of the server where the account is located. */
	public $server;

	/** Port where connect to on the server. */
	public $port;

	/** Account logging username. */
	public $username;

	/** Account logging password. */
	public $password;
	
	/** description of the account. */
	public $description;
	
	//Folders that will be automatically created on first request on them
  private static $aAutoCreateFolders = array('trash'=>1,'drafts'=>1,'sent'=>1,'spam'=>1,'files'=>1);
  private static $aAutoCreateFolderTypes = array('trash'=>'M','drafts'=>'M','sent'=>'M','spam'=>'M','files'=>'F');

	
  public $accountID;

	/**
	  @brief Create a new account object.
	  @param $server Name of the server where the account is located.
	  @param $port Port where connect to on the server.
	  @param $username Account logging username.
	  @param $password Account logging password.
	 */
	protected function __construct($server, $port, $username, $password,$properties)
	{

		$this->gwAccount = null;
		$this->folders	= array('main' => array(),
								            'gw'	=> array(),
								            'quarantine' => array());
		$this->server	= $server;
		$this->port	  = $port;
		$this->username  = $username;
		$this->password  = $password;


    
    if ($properties)
      foreach($properties as $key =>$val){
          $this->$key = $val;
      }

	}

	/**
	  @brief Edit account properties.
	  @param $properties Properties as an array of (property => value).
	 */
	final public function edit($properties)
	{
		foreach ($properties as $property => $value)
			$this->$property = $value;
	}

	/**
	  @brief Append associated GroupWare account.
	  @param GroupWareAccount object.
	 */
	final public function appendGroupWareAccount($gwAccount)
	{
		$this->gwAccount = $gwAccount;
	}

	/**
	  @brief Check if the account has GroupWare account appended.
	  @return True if so.
	 */
	final public function isGroupWare(&$logged = true)
	{
	  $logged = false;
	  if ($this->gwAccount->bLogged) $logged = true;
		return $this->gwAccount ? true : false;
	}

	/**
	  @brief Get the list of folders.
	  @return The list as an array of Folder objects.
	 */
	public function getFolders()
	{
	  // Retrieve list of gw folders
		if ($this->gwAccount) $this->folders["gw"] = $this->gwAccount->getFolders();

		// List of IMAP folders
		$return = $this->folders['main'];
    
    //Merge folders - viz. document Merak Webmail Folders.doc 
    if ($this->folders['gw'])
    foreach($this->folders['gw'] as $fid => $folder)
          if ($folder->type!='M') $return[$fid] = $folder; 

    //Append quarantine folders
    if ($this->primary)
      foreach($this->folders['quarantine'] as $folder)
        $return[$folder->name] = $folder;

    return $return;
	}

	/**
	  @brief Get a folder.
	  @param $name Name of the folder.
	  @param[out] $type Type of the folder ('main' or 'gw' or 'quarantine').
	  @return Folder object.
	 */
  public function getFolder($name, &$type = '',$logError = true)
  {
    //If quarantine folder exists , return it
    if (isset($this->folders["quarantine"][$name])) {
      $type = 'quarantine';
      return $this->folders["quarantine"][$name];
    }
    //Check if folder exists in GW and if it is really GW folder , return it
    if ($this->gwAccount && (!$type || $type=='gw')){
      try {

          if ($oFolder = $this->gwAccount->getFolder(str_replace("\\","/",$name), &$type))
          {
              if ($oFolder->type!='M')
              {
                $type = 'gw';
                return $oFolder;
                
              }
          }
      } catch (Exc $e) {
       // folder does not exist in GW, continue
      }
    }

    //Check if folder exists in IMAP
    if (isset($this->folders['main'][$name])) {
    
          $type = 'main';
          return $this->folders['main'][$name];
    
    //No folder found
    } else {
          
          throw new Exc('Folder does not exist: ' . $name,'folder_existence',false,$logError);
    }
  }
	
	public function getFolderWithAutoCreate($name) {
	    define('EXCEPTION_LOG',0);
			global $aError;
			// Try to get folder
      try {
			  
			  try{
        // Try to get mail folder
        $type='main';

				$oFolder = $this->getFolder($name,$type,false);

        //If folder exists in GW and do not have M type, return that folder
        if (isset($this->folders["gw"][$name]) && $this->folders["gw"][$name]->type!='M')
          return $this->folders["gw"][$name];

				//Try to load GW folder that is not loaded yet
				}catch(Exc $e){
				  $type='';
          $oFolder = $this->getFolder($name,$type,false);
        }
				
      }
      //Autocreate folder in case the folder does not exist
			catch(Exc $e) {
      
	          $checkname = strtolower($name);
            if (self::$aAutoCreateFolders[$checkname])
            {
 				       // try to create the folder with its default name
                //Work with GW or with IMAP
              if(self::$aAutoCreateFolderTypes[$checkname]!='M')
                $oAccount = $this->gwAccount;
              else{ 
                $oAccount = $this;
              }
              $oAccount->createFolder($name,self::$aAutoCreateFolderTypes[$checkname]);           
              if($oAccount 
              && $oFolder = $oAccount->getFolder($name))
                return $oFolder;
              else 
                throw new Exc('Folder does not exist');
            }
        }
      define('EXCEPTION_LOG',1);
			return $oFolder;
		}

	/**
	  @brief Create a new folder.
	  @param $name Name of the folder.
	 */
	protected function createFolder($name,$type='',$virtual = false)
	{
	  //Check whether folder exists in imap or in groupware
		if (isset($this->folders['main'][$name])
			|| isset($this->folders['gw'][$name]))
		{
			throw new Exc('Folder already exists');
		}
	}

	/**
	  @brief Delete a folder.
	  @param $name Name of the folder.
	 */
	public function deleteFolder($name)
	{
		$folder = $this->getFolder($name, &$type);
		$folder->delete();
		unset($this->folders[$type][$name]);
	}

	/**
	  @brief Rename a folder.
	  @param $oldName Name of the folder.
	  @param $newName New name of the folder.
	 */
	public function renameFolder($oldName, $newName)
	{
		if ($oldName === $newName)
			return;

		if (isset($this->folders['main'][$newName])
			|| isset($this->folders['gw'][$newName]))
		{
			throw new Exc('Folder already exists');
		}

		$folder = $this->getFolder($oldName, $type);
		$folder->rename($newName);
		$this->folders[$type][$newName] = $this->folders[$type][$oldName];
		unset($this->folders[$type][$oldName]);
	}
}
require_once('inc/gw/account.php');
require_once('inc/cache/account.php');

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/account.php <==
<?php

/**
  @class Account
  @brief Class representing a generic account.
  @author Martin Zlomek
  @date 12-02-2006
 */
abstract class Account {
	/** Optional GroupWare account. */
	public $gwAccount;

	/** List of folders. */
	public $folders;

	/** Name of the server where the account is located. */
	public $server;

	/** Port where connect to on the server. */
	public $port;

	/** Account logging username. */
	public $username;

	/** Account logging password. */
	public $password;
	
	/** description of the account. */
	public $description;
	
	//Folders that will be automatically created on first request on them
  //private static $aAutoCreateFolders = array('trash'=>1,'drafts'=>1,'sent'=>1,'spam'=>1,'files'=>1);
  //private static $aAutoCreateFolderTypes = array('trash'=>'M','drafts'=>'M','sent'=>'M','spam'=>'M','files'=>'F');

	
  public $accountID;

	/**
	  @brief Create a new account object.
	  @param $server Name of the server where the account is located.
	  @param $port Port where connect to on the server.
	  @param $username Account logging username.
	  @param $password Account logging password.
	 */
	protected function __construct($server, $port, $username, $password,$properties)
	{

		$this->gwAccount = null;
		$this->folders	= array('main' => array(),
								            'gw'	=> array(),
								            'quarantine' => array());
		$this->server	= $server;
		$this->port	  = $port;
		$this->username  = $username;
		$this->password  = $password;


    
    if ($properties)
      foreach($properties as $key =>$val){
          $this->$key = $val;
      }

	}

	/**
	  @brief Edit account properties.
	  @param $properties Properties as an array of (property => value).
	 */
	final public function edit($properties)
	{
		foreach ($properties as $property => $value)
			$this->$property = $value;
	}

	/**
	  @brief Append associated GroupWare account.
	  @param GroupWareAccount object.
	 */
	final public function appendGroupWareAccount($gwAccount)
	{
		$this->gwAccount = $gwAccount;
	}
  
  /**
	  @brief Append associated GroupWare account.
	  @param GroupWareAccount object.
	 */
	final public function appendRSSAccount($rssAccount)
	{
		$this->rssAccount = $rssAccount;
	}
  
  /**
	  @brief Append associated GroupWare account.
	  @param GroupWareAccount object.
	 */
	final public function isRSS()
	{
      return $this->rssAccount ? true : false;
	}
	/**
	  @brief Check if the account has GroupWare account appended.
	  @return True if so.
	 */
	final public function isGroupWare(&$logged = true)
	{
	  $logged = false;
	  if ($this->gwAccount->bLogged) $logged = true;
		return $this->gwAccount ? true : false;
	}

	/**
	  @brief Get the list of folders.
	  @return The list as an array of Folder objects.
	 */
	public function getFolders()
	{
	  // Retrieve list of gw folders
		if ($this->gwAccount) $this->folders["gw"] = $this->gwAccount->getFolders();

		// List of IMAP folders
		$return = $this->folders['main'];
    
    //Merge folders - viz. document Merak Webmail Folders.doc 
    if ($this->folders['gw'])
    foreach($this->folders['gw'] as $fid => $folder)
          if ($folder->type!='M') $return[$fid] = $folder; 

    //Append quarantine folders
    if ($this->primary)
      foreach($this->folders['quarantine'] as $folder)
        $return[$folder->name] = $folder;

    return $return;
	}

	/**
	  @brief Get a folder.
	  @param $name Name of the folder.
	  @param[out] $type Type of the folder ('main' or 'gw' or 'quarantine').
	  @return Folder object.
	 */
  public function getFolder($name, &$type = '',$logError = true)
  {
    //If quarantine folder exists , return it
    if (isset($this->folders["quarantine"][$name])) {
      $type = 'quarantine';
      return $this->folders["quarantine"][$name];
    }
    //Check if folder exists in GW and if it is really GW folder , return it
    if ($this->gwAccount && (!$type || $type=='gw')){
      try {

          if ($oFolder = $this->gwAccount->getFolder(str_replace("\\","/",$name), &$type))
          {
              if ($oFolder->type!='M')
              {
                $type = 'gw';
                return $oFolder;
                
              }
          }
      } catch (Exc $e) {
       // folder does not exist in GW, continue
      }
    }

    //Check if folder exists in IMAP
    if (isset($this->folders['main'][$name])) {
    
          $type = 'main';
          return $this->folders['main'][$name];
    
    //No folder found
    } else {
          
          throw new Exc('folder_does_not_exist',$name,false,$logError);
    }
  }
	
	public function getFolderWithAutoCreate($name,$ftype = 'main') {
	    define('EXCEPTION_LOG',0);
			global $aError;

			
			// Try to get folder
      try {
			  
			  try{
        // Try to get mail folder
        $type='main';

				$oFolder = $this->getFolder($name,$type,false);

        //If folder exists in GW and do not have M type, return that folder
        if (isset($this->folders["gw"][$name]) && $this->folders["gw"][$name]->type!='M')
          return $this->folders["gw"][$name];

				//Try to load GW folder that is not loaded yet
				}catch(Exc $e){
				  $type='';
          $oFolder = $this->getFolder($name,$type,false);
        }
				
      }
      //Autocreate folder in case the folder does not exist
			catch(Exc $e) {
      
	          $checkname = strtolower($name);
            //if (self::$aAutoCreateFolders[$checkname])
          //  {
 				       // try to create the folder with its default name
                //Work with GW or with IMAP

              if($ftype=='main'){
                $oAccount = $this;
              }else{ 
                $oAccount = $this->gwAccount;  
              }

              
              $oAccount->createFolder($name,$ftype);           
              if($oAccount 
              && $oFolder = $oAccount->getFolder($name))
                return $oFolder;
              else 
                throw new Exc('folder_does_not_exist',$name);
          //  }
        }
      define('EXCEPTION_LOG',1);
			return $oFolder;
		}

	/**
	  @brief Create a new folder.
	  @param $name Name of the folder.
	 */
	protected function createFolder($name,$type='',$virtual = false)
	{
	  //Check whether folder exists in imap or in groupware
		if (isset($this->folders['main'][$name])
			|| isset($this->folders['gw'][$name]))
		{
			throw new Exc('folder_already_exists',$name);
		}
	}

	/**
	  @brief Delete a folder.
	  @param $name Name of the folder.
	 */
	public function deleteFolder($name)
	{

		$folder = &$this->getFolder($name, &$type);
		unset($this->folders["main"][$name]);
		
		$folder->delete();
	}

	/**
	  @brief Rename a folder.
	  @param $oldName Name of the folder.
	  @param $newName New name of the folder.
	  @ It is not used now  - Folder->rename is used
	 */
	public function renameFolder($oldName, $newName)
	{
		if ($oldName === $newName)
			return;

		if (isset($this->folders['main'][$newName])
			|| isset($this->folders['gw'][$newName]))
		{
			throw new Exc('folder_already_exists',$name);
		}

		$folder = $this->getFolder($oldName, $type);
		$folder->rename($newName);
		$this->folders[$type][$newName] = $this->folders[$type][$oldName];
		unset($this->folders[$type][$oldName]);
	}
}
require_once('inc/gw/account.php');
require_once('inc/cache/account.php');

?>
